@@ -30,7 +30,7 @@ router.register(r'accessories', AccessoryViewSet)
 router.register(r'hardwares', HardwareViewSet)
 router.register(r'channel', ChannelViewSet)
 router.register(r'calibration', CalibrationViewSet)
-router.register(r'hubs', HubViewSet)
+router.register(r'hubs', HubViewSet, basename='hubs')
 router.register(r'io', IOViewSet)
 
 from data.views.views import index
