@@ -606,6 +606,10 @@ class HubViewSet(viewsets.ModelViewSet):
     queryset = Hub.objects.all()
     serializer_class = HubSerializer
     renderer_classes = (renderers.JSONRenderer, renderers.TemplateHTMLRenderer)
+    context_object_name = 'all_hubs'
+
+    def get_queryset(self):
+        return Hub.objects.all()
 
     def listHubHardware(self, hub_id):
         hardware = Hub.objects.get(pk=hub_id).hardware_set.all()
